@@ -1568,6 +1568,7 @@ gtk_source_view_paint_line_background (GtkTextView    *text_view,
 			 line_rect.width - 1, line_rect.height - 1);
 	cairo_stroke_preserve (cr);
 	cairo_fill (cr);
+	cairo_destroy (cr);
 }
 
 static void
@@ -1796,7 +1797,7 @@ draw_spaces_at_iter (cairo_t       *cr,
 		draw_space_at_iter (cr, GTK_TEXT_VIEW (view), iter, rect);
 	}
 	else if (view->priv->draw_spaces & GTK_SOURCE_DRAW_SPACES_NEWLINE &&
-		 gtk_text_iter_ends_line (iter))
+		 gtk_text_iter_ends_line (iter) && !gtk_text_iter_is_end (iter))
 	{
 		draw_newline_at_iter (cr, GTK_TEXT_VIEW (view), iter, rect);
 	}
